Module blaxel.core.client.models.core_spec_configurations
=========================================================

Classes
-------

`CoreSpecConfigurations(key: blaxel.core.client.types.Unset | ForwardRef('SpecConfiguration') = <blaxel.core.client.types.Unset object>)`
:   Optional configurations for the object
    
    Attributes:
        key (Union[Unset, SpecConfiguration]): Configuration, this is a key value storage. In your object you can
            retrieve the value with config[key]
    
    Method generated by attrs for class CoreSpecConfigurations.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `key`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :